# codat-assess

<!-- Start SDK Installation -->
## SDK Installation

```bash
pip install codat-assess
```
<!-- End SDK Installation -->

## SDK Example Usage
<!-- Start SDK Example Usage -->
```python
import codat
from codat.models import operations, shared

s = codat.Codat(
    security=shared.Security(
        auth_header="YOUR_API_KEY_HERE",
    ),
)


req = operations.GetAccountCategoryRequest(
    account_id="unde",
    company_id="deserunt",
    connection_id="porro",
)
    
res = s.categories.get_account_category(req)

if res.categorised_account is not None:
    # handle response
```
<!-- End SDK Example Usage -->

<!-- Start SDK Available Operations -->
## SDK Available Operations


### categories

* `get_account_category` - Get suggested and/or confirmed category for a specific account
* `list_accounts_categories` - List suggested and confirmed account categories
* `list_available_account_categories` - List account categories
* `update_account_category` - Patch account categories
* `update_accounts_categories` - Confirm categories for accounts

### data_integrity

* `get_data_integrity_details` - Lists data integrity details for date type
* `get_data_integrity_status` - Get data integrity status
* `get_data_integrity_summaries` - Get data integrity summary

### excel_reports

* `get_accounting_marketing_metrics` - Get the marketing metrics from an accounting source for a given company.
* `get_excel_report` - Download generated excel report
* `make_request_to_download_excel_report` - Request an Excel report for download
* `request_excel_report_for_download` - Request an Excel report for download

### reports

* `get_accounts_for_enhanced_balance_sheet` - Enhanced Balance Sheet Accounts
* `get_accounts_for_enhanced_profit_and_loss` - Enhanced Profit and Loss Accounts
* `get_commerce_customer_retention_metrics` - Get the customer retention metrics for a specific company.
* `get_commerce_lifetime_value_metrics` - Get the lifetime value metric for a specific company.
* `get_commerce_orders_metrics` - Get order information for a specific company
* `get_commerce_refunds_metrics` - Get the refunds information for a specific company
* `get_commerce_revenue_metrics` - Commerce Revenue Metrics
* `get_enhanced_balance_sheet` - Enhanced Balance Sheet
* `get_enhanced_cash_flow_transactions` - Get enhanced cash flow report
* `get_enhanced_financial_metrics` - List finanicial metrics
* `get_enhanced_profit_and_loss` - Enhanced Profit and Loss
* `get_recurring_revenue_metrics` - Get key metrics for subscription revenue
* `request_recurring_revenue_metrics` - Request production of key subscription revenue metrics
<!-- End SDK Available Operations -->

### SDK Generated by [Speakeasy](https://docs.speakeasyapi.dev/docs/using-speakeasy/client-sdks)
